@@ -40,7 +40,7 @@ main (int argc, char **argv)
    FILE *fd;
    char *fname;
    char *model;
-   int dskloc;
+   long dskloc;
    int i;
    int j;
    int cyls, heads, sectrk, overhead, sectlen;
@@ -225,7 +225,7 @@ main (int argc, char **argv)
 #ifdef DEBUG
       printf ("   cyl = %d, head = %d, sector = %d\n",
 	       cyl, head, start);
-      printf ("   dskloc = %d\n", dskloc);
+      printf ("   dskloc = %ld\n", dskloc);
 #endif
 
       /*
@@ -247,7 +247,7 @@ main (int argc, char **argv)
       /*
       ** Dump it
       */
-      printf ("\ncyl %d head %d sect %d dskloc = %d:\n", cyl, head, j, dskloc);
+      printf ("\ncyl %d head %d sect %d dskloc = %ld:\n", cyl, head, j, dskloc);
       HEXDUMP (stdout, buf, sectlen, 0);
    }
 
