@@ -44,8 +44,10 @@ main (int argc, char **argv)
    int i, j;
    int diskndx;
    int verbose;
+   int geoonly;
 
    verbose = FALSE;
+   geoonly = FALSE;
    diskfile = NULL;
    diskname = NULL;
 
@@ -66,6 +68,10 @@ main (int argc, char **argv)
 	    diskname = argv[i];
 	    break;
 
+	 case 'g':
+	    geoonly = TRUE;
+	    break;
+
 	 case 'v':
 	    verbose = TRUE;
 	    break;
@@ -157,16 +163,19 @@ main (int argc, char **argv)
    dskwriteint (dfd, (disks[diskndx].overhead << 8) | disks[diskndx].sectrk);
    dskwriteint (dfd, disks[diskndx].bytsec);
 
-   /*
-   ** Write the disk image
-   */
-
-   for (i = 0; i < disksize; i++)
+   if (!geoonly)
    {
-      if (i == 0xA5) /* Mark INV done */
-	 fputc (0x02, dfd);
-      else
-	 fputc (0, dfd);
+      /*
+      ** Write the disk image
+      */
+
+      for (i = 0; i < disksize; i++)
+      {
+	 if (i == 0xA5) /* Mark INV done */
+	    fputc (0x02, dfd);
+	 else
+	    fputc (0, dfd);
+      }
    }
    
    fclose (dfd);
